
django-models-extensions: Django Models Extensions
==================================================


Installing
-------------------

You can install or upgrade django-models-extensions with:

.. code:: shell

    $ pip install django-models-extensions --upgrade

Or you can install from source with:

.. code:: shell

    $ git clone https://github.com/lampofearth/django-models-extensions --recursive
    $ cd django-models-extensions
    $ python setup.py install


Examples
-------------------

``django-models-extensions`` examples lives at `github.com/lampofearth/django-models-extensions/wiki <https://github.com/lampofearth/django-models-extensions/wiki>`_.

License
-------------------

You may copy, distribute and modify the software provided that modifications
are described and licensed for free under `LGPL-3 <https://www.gnu.org/licenses/lgpl-3.0.html>`_.
Derivatives works (including modifications or anything statically linked to the library)
can only be redistributed under LGPL-3, but applications that us